@@ -1,5 +1,5 @@
 /*
- *  $Id: chargen_server.c,v 1.11 2004/11/17 22:46:17 tuexen Exp $
+ *  $Id: chargen_server.c 742 2005-09-01 15:44:24Z tuexen $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -418,7 +418,7 @@ int main(int argc, char **argv)
     SCTP_ulpCallbacks chargenUlp;
     SCTP_LibraryParameters params;
     SCTP_InstanceParameters instanceParameters;
-    short sctpInstance;
+    int sctpInstance;
     
     /* initialize the discard_ulp variable */
     chargenUlp.dataArriveNotif           = &dataArriveNotif;
@@ -448,9 +448,9 @@ int main(int argc, char **argv)
                                          noOfLocalAddresses, localAddressList,
                                          chargenUlp);
 
-    SCTP_getAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_getAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
     instanceParameters.maxSendQueue = SEND_QUEUE_SIZE;
-    SCTP_setAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_setAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
 
     /* run the event handler forever */
     while (1) {
