@@ -1,5 +1,5 @@
 /*
- *  $Id: combined_server.c,v 1.10 2004/11/19 20:11:47 tuexen Exp $
+ *  $Id: combined_server.c 742 2005-09-01 15:44:24Z tuexen $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -584,7 +584,7 @@ int main(int argc, char **argv)
     SCTP_ulpCallbacks echoUlp, discardUlp, daytimeUlp, chargenUlp;
     SCTP_LibraryParameters params;
     SCTP_InstanceParameters instanceParameters;
-    short sctpInstance;
+    int sctpInstance;
 
     /* initialize the echo_ulp variable */
     echoUlp.dataArriveNotif              = &echoDataArriveNotif;
@@ -665,9 +665,9 @@ int main(int argc, char **argv)
                                          noOfLocalAddresses, localAddressList,
                                          chargenUlp);
     
-    SCTP_getAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_getAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
     instanceParameters.maxSendQueue = SEND_QUEUE_SIZE;
-    SCTP_setAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_setAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
 
     /* run the event handler forever */
     while (1) {
