@@ -1,5 +1,5 @@
 /*
- *  $Id: echo_tool.c,v 1.9 2004/11/19 20:11:47 tuexen Exp $
+ *  $Id: echo_tool.c 742 2005-09-01 15:44:24Z tuexen $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -570,7 +570,7 @@ measurementTimerRunOffFunction(unsigned int timerID, void *parameter1, void *par
 
 int main(int argc, char **argv)
 {
-    unsigned short sctpInstance;
+    int sctpInstance;
     SCTP_ulpCallbacks echoUlp;
     SCTP_InstanceParameters instanceParameters;
     SCTP_LibraryParameters params;
@@ -612,13 +612,13 @@ int main(int argc, char **argv)
 
     /* set the TOS field */
 
-    SCTP_getAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_getAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
     instanceParameters.maxSendQueue = 0;
     instanceParameters.ipTos=tosByte;
-    SCTP_setAssocDefaults(sctpInstance, &instanceParameters);
+    SCTP_setAssocDefaults((unsigned short)sctpInstance, &instanceParameters);
     
     if (startAssociation) {
-        SCTP_associate(sctpInstance, MAXIMUM_NUMBER_OF_OUT_STREAMS, destinationAddress, remotePort, &ulpData[0]);
+        SCTP_associate((unsigned short)sctpInstance, MAXIMUM_NUMBER_OF_OUT_STREAMS, destinationAddress, remotePort, &ulpData[0]);
     }
     
     if (doMeasurements) {
