@@ -1,5 +1,5 @@
 /*
- *  $Id: chunkHandler.c,v 1.16 2004/11/17 21:07:57 tuexen Exp $
+ *  $Id: chunkHandler.c 704 2005-08-09 16:40:18Z dreibh $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -73,11 +73,11 @@
 #define MAX_CHUNKS 8
 
 #ifndef IN_EXPERIMENTAL
-#define	IN_EXPERIMENTAL(a)	((((long int) (a)) & 0xf0000000) == 0xf0000000)
+#define  IN_EXPERIMENTAL(a)   ((((long int) (a)) & 0xf0000000) == 0xf0000000)
 #endif
 
 #ifndef IN_BADCLASS
-#define	IN_BADCLASS(a)		IN_EXPERIMENTAL((a))
+#define  IN_BADCLASS(a)    IN_EXPERIMENTAL((a))
 #endif
 
 /* Other constants */
@@ -158,7 +158,7 @@ static gint32 retrieveVLParamFromString(guint16 paramType, guchar * mstring, gui
     while (curs < length) {
         param_header = (SCTP_vlparam_header *) & mstring[curs];
         pType = ntohs(param_header->param_type);
-        
+
         if (ntohs(param_header->param_length) < 4) {
             error_log(ERROR_MINOR, "Program/Peer implementation problem : parameter length 0");
             return -1;
@@ -253,6 +253,10 @@ setIPAddresses(unsigned char *mstring, guint16 length, union sockunion addresses
                 */
                 event_logii(VVERBOSE, "Got IPv4 address %x, discard: %s !",
                                         ntohl(address->dest_addr.sctp_ipv4), (discard==TRUE)?"TRUE":"FALSE");
+                if(nAddresses >= MAX_NUM_ADDRESSES) {
+                   error_log(ERROR_MINOR, "Too many addresses found during IPv4 reading");
+                   discard = TRUE;
+                }
 
                 if (discard == FALSE) {
                     new_found = TRUE;
@@ -271,7 +275,7 @@ setIPAddresses(unsigned char *mstring, guint16 length, union sockunion addresses
                         addresses[v4found].sin.sin_addr.s_addr = address->dest_addr.sctp_ipv4;
                         nAddresses++; v4found++;
                         (*peerTypes) |= SUPPORT_ADDRESS_TYPE_IPV4;
-                        event_logi(VERBOSE, "Found NEW IPv4 Address = %x", address->dest_addr.sctp_ipv4);
+                        event_logi(VERBOSE, "Found NEW IPv4 Address = %x", ntohl(address->dest_addr.sctp_ipv4));
                     } else {
                         event_log(VERBOSE, "IPv4 was in the INIT or INIT ACK chunk more than once");
                     }
@@ -337,9 +341,15 @@ setIPAddresses(unsigned char *mstring, guint16 length, union sockunion addresses
                 if (IN6_IS_ADDR_MULTICAST((struct in6_addr*)&(address->dest_addr.sctp_ipv6))) discard = TRUE;
                 if (IN6_IS_ADDR_V4COMPAT((struct in6_addr*)&(address->dest_addr))) discard = TRUE;
 #endif
-                if (adl_filterInetAddress(&tmp_su, filterFlags) == FALSE) discard = TRUE;
+                if (adl_filterInetAddress(&tmp_su, filterFlags) == FALSE) {
+                   discard = TRUE;
+                }
+                if(nAddresses >= MAX_NUM_ADDRESSES) {
+                   error_log(ERROR_MINOR, "Too many addresses found during IPv6 reading");
+                   discard = TRUE;
+                }
                 event_logiii(VERBOSE, "Found IPv6 Address - discard=%s - #v4=%d - #v6=%d !",
-                    (discard==TRUE)?"TRUE":"FALSE", v4found, v6found);
+                             (discard==TRUE)?"TRUE":"FALSE", v4found, v6found);
                 if (discard == FALSE) {
                     new_found = TRUE;
 
@@ -348,10 +358,15 @@ setIPAddresses(unsigned char *mstring, guint16 length, union sockunion addresses
                             if (adl_equal_address(&tmp_su, &addresses[idx]) == TRUE) {
                                 new_found = FALSE;
 #if defined (LINUX)
-                                event_logiiii(VERBOSE, "Found OLD IPv6 Address %x:%x:%x:%x !",
-                                        tmp_su.sin6.sin6_addr.s6_addr32[0], tmp_su.sin6.sin6_addr.s6_addr32[1],
-                                        tmp_su.sin6.sin6_addr.s6_addr32[2],
-                                        tmp_su.sin6.sin6_addr.s6_addr32[3]);
+                                event_logiiiiiiii(VERBOSE, "Found OLD IPv6 Address %x:%x:%x:%x:%x:%x:%x:%x!",
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[0]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[1]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[2]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[3]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[4]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[5]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[6]),
+                                                  ntohs(tmp_su.sin6.sin6_addr.s6_addr16[7]));
 #endif
                             }
                     }
@@ -364,18 +379,21 @@ setIPAddresses(unsigned char *mstring, guint16 length, union sockunion addresses
                         addresses[nAddresses].sin6.sin6_scope_id = htonl(0);
 #endif
 
-
-
                         memcpy(addresses[nAddresses].sin6.sin6_addr.s6_addr,
                                address->dest_addr.sctp_ipv6, sizeof(struct in6_addr));
                         nAddresses++; v6found++;
                         (*peerTypes) |= SUPPORT_ADDRESS_TYPE_IPV6;
 #if defined (LINUX)
-                        event_logiiii(VERBOSE, "Found NEW IPv6 Address %x:%x:%x:%x !",
-                                tmp_su.sin6.sin6_addr.s6_addr32[0], tmp_su.sin6.sin6_addr.s6_addr32[1],
-                                tmp_su.sin6.sin6_addr.s6_addr32[2],
-                                tmp_su.sin6.sin6_addr.s6_addr32[3]);
-#endif 
+                        event_logiiiiiiii(VERBOSE, "Found NEW IPv6 Address %x:%x:%x:%x:%x:%x:%x:%x!",
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[0]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[1]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[2]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[3]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[4]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[5]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[6]),
+                                          ntohs(tmp_su.sin6.sin6_addr.s6_addr16[7]));
+#endif
 
                     }
                 }
@@ -702,13 +720,13 @@ gboolean ch_getPRSCTPfromCookie(ChunkID cookieCID)
         pType =  ntohs(vl_Ptr->param_type);
         pLen  =  ntohs(vl_Ptr->param_length);
         event_logiii(VERBOSE, "Scan variable parameters in cookie: Got type %u, len: %u, position %u",pType, pLen, curs);
-        
+
         /* peer error - ignore - should send an error notification */
-        if (pLen < 4) return FALSE; 
-        
+        if (pLen < 4) return FALSE;
+
         if (pType == VLPARAM_PRSCTP) {
             /* ha, we got one ! */
-            
+
             if (pLen >= 4){
                  event_log(VERBOSE, "Peer Supports PRSCTP");
                  result = TRUE; /* peer supports it  */
@@ -748,9 +766,9 @@ gboolean ch_getPRSCTPfromInitAck(ChunkID initAckCID)
         vl_Ptr = (SCTP_vlparam_header *) & ack_string[curs];
         pType =  ntohs(vl_Ptr->param_type);
         pLen  =  ntohs(vl_Ptr->param_length);
-        
+
         if (pLen < 4) return  FALSE; /* peer error - ignore - should send an error notification */
-        
+
         event_logiii(VERBOSE, "Scan variable parameters: Got type %u, len: %u, position %u",pType, pLen, curs);
 
         if (pType == VLPARAM_PRSCTP) {
@@ -793,9 +811,9 @@ int ch_enterPRSCTPfromInit(ChunkID initAckCID, ChunkID initCID)
         vl_initPtr = (SCTP_vlparam_header *) & init_string[curs];
         pType =  ntohs(vl_initPtr->param_type);
         pLen  =  ntohs(vl_initPtr->param_length);
-        
-        if (pLen < 4) result = -1; /* peer error - ignore - should send an error notification */        
-        
+
+        if (pLen < 4) result = -1; /* peer error - ignore - should send an error notification */
+
         event_logiii(VERBOSE, "Scan variable parameters: Got type %u, len: %u, position %u",pType, pLen, curs);
 
         if (pType == VLPARAM_PRSCTP) {
@@ -872,7 +890,7 @@ ch_enterCookieVLP(ChunkID initCID, ChunkID initAckID,
 
         cookie->ck.src_port = mdi_readLastFromPort();
         cookie->ck.dest_port = mdi_readLastDestPort();
-        
+
         for (count = 0; count <  num_local_Addresses; count++) {
             switch(sockunion_family(&(local_Addresses[count]))) {
                 case AF_INET :
@@ -1015,9 +1033,9 @@ int ch_enterUnrecognizedParameters(ChunkID initCID, ChunkID AckCID, unsigned int
         vl_initPtr = (SCTP_vlparam_header *) & init_string[curs];
         pType = ntohs(vl_initPtr->param_type);
         pLen =   ntohs(vl_initPtr->param_length);
-        
+
         if (pLen < 4)  return -1;
-        
+
         event_logiii(VERBOSE, "Scan variable parameters: type %u, len: %u, position %u",pType, pLen, curs);
 
         if (pType == VLPARAM_COOKIE_PRESERV ||
@@ -1025,7 +1043,7 @@ int ch_enterUnrecognizedParameters(ChunkID initCID, ChunkID AckCID, unsigned int
             pType == VLPARAM_IPV4_ADDRESS ||
             pType == VLPARAM_IPV6_ADDRESS ||
             pType == VLPARAM_PRSCTP) {
-            
+
             curs += pLen;
             /* take care of padding */
             while ((curs % 4) != 0) curs++;
@@ -1049,7 +1067,7 @@ int ch_enterUnrecognizedParameters(ChunkID initCID, ChunkID AckCID, unsigned int
             curs += pLen;
             /* take care of padding */
             while ((curs % 4) != 0) curs++;
-            
+
         }
     }
     return 0;
@@ -1083,7 +1101,7 @@ int ch_enterUnrecognizedErrors(ChunkID initAckID,
     *peerSupportsADDIP = FALSE;
 
     /* this is the default */
-    *peerSupportsIPV4 = TRUE; 
+    *peerSupportsIPV4 = TRUE;
     *peerSupportsIPV6 = TRUE;
 
     if (chunks[initAckID] == NULL) {
@@ -1122,7 +1140,7 @@ int ch_enterUnrecognizedErrors(ChunkID initAckID,
         event_logiii(VERBOSE, "Scan variable parameters: type %u, len: %u, position %u",pType, pLen, curs);
 
         if (pLen < 4) return -1;
-        
+
         if (pType == VLPARAM_COOKIE_PRESERV || pType == VLPARAM_COOKIE ||
             pType == VLPARAM_SUPPORTED_ADDR_TYPES) {
 
@@ -1135,7 +1153,7 @@ int ch_enterUnrecognizedErrors(ChunkID initAckID,
             vl_optionsPtr = (SCTP_vlparam_header *) & ack_string[curs+sizeof(SCTP_vlparam_header)];
             oType =  ntohs(vl_optionsPtr->param_type);
             oLen =   ntohs(vl_optionsPtr->param_length);
-            
+
             if (oType ==  VLPARAM_PRSCTP) {
                 *peerSupportsPRSCTP = FALSE;
                 curs += pLen;
@@ -1158,7 +1176,7 @@ int ch_enterUnrecognizedErrors(ChunkID initAckID,
                 /* take care of padding */
                 while ((curs % 4) != 0) curs++;
             } else { /* this is an unknown unknwon parameter....very strange...ignore it */
-		    /* this is probably a bakeoff test.... :-)   */
+          /* this is probably a bakeoff test.... :-)   */
                 curs += pLen;
                 /* take care of padding */
                 while ((curs % 4) != 0) curs++;
@@ -1418,7 +1436,7 @@ unsigned int ch_cookieLifeTime(ChunkID chunkID)
 }
 
 /**
- *  ch_getSupportedAddressTypes() processes a INIT or INIT-ACK chunk and 
+ *  ch_getSupportedAddressTypes() processes a INIT or INIT-ACK chunk and
  *  returns a value that indicates, which address types are supported by the peer.
  */
 unsigned int ch_getSupportedAddressTypes(ChunkID chunkID)
@@ -1447,11 +1465,11 @@ unsigned int ch_getSupportedAddressTypes(ChunkID chunkID)
             /* found supported address types parameter */
             param = (SCTP_supported_addresstypes*)
                         &((SCTP_init *)chunks[chunkID])->variableParams[vl_param_curs];
-                        
+
             pLen = ntohs(param->vlparam_header.param_length);
-            
+
             if (pLen < 4 || pLen > 12) return result;
-            
+
             while(pos < pLen) {
                 if (ntohs(param->address_type[num]) == VLPARAM_IPV4_ADDRESS)
                     result |= SUPPORT_ADDRESS_TYPE_IPV4;
@@ -1642,7 +1660,7 @@ ChunkID ch_cookieInitFixed(ChunkID chunkID)
 
 
 
-/* ch_cookieInitAckFixed creates an initAck chunk from the fixed part of an initAck contained in a 
+/* ch_cookieInitAckFixed creates an initAck chunk from the fixed part of an initAck contained in a
    cookie and returns its chunkID */
 ChunkID ch_cookieInitAckFixed(ChunkID chunkID)
 {
@@ -1718,10 +1736,10 @@ int ch_cookieIPDestAddresses(ChunkID chunkID, unsigned int mySupportedTypes,
                                                    (guint16)vl_param_total_length, temp_addresses,
                                                    peerSupportedAddressTypes, mySupportedTypes,
                                                    lastSource, FALSE, TRUE);
-        if (nAddresses >
+        if (nAddresses !=
             no_loc_ipv4_addresses + no_remote_ipv4_addresses +
             no_loc_ipv6_addresses + no_remote_ipv6_addresses) {
-            error_log(ERROR_FATAL, "Found more addresses than should be in the cookie !");
+            error_log(ERROR_FATAL, "Found more or less addresses than should be in the cookie !");
         }
 
         memcpy(addresses, &temp_addresses[no_loc_ipv4_addresses],
@@ -1938,7 +1956,7 @@ ChunkID ch_makeHeartbeat(unsigned int sendingTime, unsigned int pathID)
                       heartbeatChunk->hmac[i * 4], heartbeatChunk->hmac[i * 4 + 1],
                       heartbeatChunk->hmac[i * 4 + 2], heartbeatChunk->hmac[i * 4 + 3]);
     }
-    
+
     enterChunk((SCTP_simple_chunk *) heartbeatChunk, "created heartbeatChunk %u ");
 
     return freeChunkID;
@@ -1959,7 +1977,7 @@ gboolean ch_verifyHeartbeat(ChunkID chunkID)
 
     MD5_CTX ctx;
 
-    
+
     if (chunks[chunkID] == NULL) {
         error_log(ERROR_MAJOR, "Invalid chunk ID");
         return FALSE;
@@ -1973,13 +1991,13 @@ gboolean ch_verifyHeartbeat(ChunkID chunkID)
         memcpy(hbSignature, heartbeatChunk->hmac, HMAC_LEN);
 
         event_log(VERBOSE, "Got signature: ");
-        
+
         for (i = 0; i < 4; i++) {
             event_logiiii(VERBOSE, "%2.2x %2.2x %2.2x %2.2x",
                       heartbeatChunk->hmac[i * 4], heartbeatChunk->hmac[i * 4 + 1],
                       heartbeatChunk->hmac[i * 4 + 2], heartbeatChunk->hmac[i * 4 + 3]);
         }
-       
+
         memset(heartbeatChunk->hmac, 0, HMAC_LEN);
 
         MD5Init(&ctx);
@@ -1998,7 +2016,7 @@ gboolean ch_verifyHeartbeat(ChunkID chunkID)
         else res = FALSE;
 
         return res;
-        
+
     } else {
         error_log(ERROR_MINOR, "ch_verifyHeartbeat: chunk type not okay");
         return FALSE;
