@@ -1,5 +1,5 @@
 /*
- *  $Id: globals.h,v 1.14 2004/12/08 14:53:16 dreibh Exp $
+ *  $Id: globals.h 686 2005-08-04 10:49:29Z dreibh $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -102,7 +102,7 @@
 #endif
 
 /** this parameter specifies the maximum number of addresses that an endpoint may have */
-#define MAX_NUM_ADDRESSES      20
+#define MAX_NUM_ADDRESSES      32
 
 
 #define SECRET_KEYSIZE  4096
@@ -135,7 +135,7 @@
                                    for instance abort of an association. */
 #define ERROR_FATAL        1    /* recovery from error was not possible, the program exits. */
 
-#define Current_error_log_ 0    /* Defines the level up to which the errors are printed.
+#define Current_error_log_ 4    /* Defines the level up to which the errors are printed.
                                    ERROR_WARNING (4) means all events are printed.
                                    This parameter could also come from a command line option */
 
@@ -188,6 +188,7 @@ typedef struct chunk_data_struct
 #define event_logiii(x,y,z,i,j)	  if (Current_event_log_ >= x) event_log1((x), __FILE__, (y), (z), (i), (j))
 #define event_logiiii(x,y,z,i,j,k)	  if (Current_event_log_ >= x) event_log1((x), __FILE__, (y), (z), (i), (j),(k))
 #define event_logiiiii(x,y,z,i,j,k,l)	  if (Current_event_log_ >= x) event_log1((x), __FILE__, (y), (z), (i), (j),(k),(l))
+#define event_logiiiiiiii(x,y,z,i,j,k,l,m,n,o)	  if (Current_event_log_ >= x) event_log1((x), __FILE__, (y), (z), (i), (j),(k),(l),(m),(n),(o))
 
 
 #define error_log(x,y)        if (Current_error_log_ >= x) error_log1((x), __FILE__, __LINE__, (y))
@@ -343,5 +344,8 @@ typedef enum  {
 #define DEFAULT_MTU_CEILING     1500
 
 
+#ifndef CHECK
+#define CHECK(cond) if(!(cond)) { fprintf(stderr, "INTERNAL ERROR in %s, line %u: condition %s is not satisfied!\n", __FILE__, __LINE__, #cond); abort(); }
+#endif
 
 #endif
