@@ -1,5 +1,5 @@
 /*
- *  $Id: reltransfer.c,v 1.11 2004/11/17 21:01:04 tuexen Exp $
+ *  $Id: reltransfer.c 686 2005-08-04 10:49:29Z dreibh $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -1192,7 +1192,7 @@ unsigned int rtx_rcv_shutdown_ctsna(unsigned int ctsna)
                      ctsna, rtx->lowest_tsn, ctsna);
         result = rtx_dequeue_up_to(ctsna , 0);
         if (result < 0) {
-            error_log(ERROR_MAJOR, "Bad ctsna arrived in shutdown  or no chunks in queue     ....");
+            event_log(VVERBOSE, "Bad ctsna arrived in shutdown or no chunks in queue");
         }
         rtx->lowest_tsn = ctsna;
         event_logi(VVERBOSE, "Updated rtx->lowest_tsn==ctsna==%u", ctsna);
