@@ -1,5 +1,5 @@
 /*
- *  $Id: sctp.h,v 1.13 2004/11/17 21:04:01 tuexen Exp $
+ *  $Id: sctp.h 629 2005-04-29 19:54:18Z tuexen $
  *
  * SCTP implementation according to RFC 2960.
  * Copyright (C) 2000 by Siemens AG, Munich, Germany.
@@ -67,7 +67,7 @@ extern "C" {
 
 #define SCTP_MAJOR_VERSION      1
 #define SCTP_MINOR_VERSION      0
-#define SCTP_TINY_VERSION       2
+#define SCTP_TINY_VERSION       5
 
 /* the maximum length of an IP address string (IPv4 or IPv6, NULL terminated) */
 /* see RFC 1884 (mixed IPv6/Ipv4 addresses)   */
@@ -504,12 +504,12 @@ int sctp_initLibrary(void);
 unsigned int sctp_getLibraryVersion(void);
 
 
-short sctp_registerInstance(unsigned short localPort,
-                            unsigned short noOfInStreams,
-                            unsigned short noOfOutStreams,
-                            unsigned int   noOfLocalAddresses,
-                            unsigned char  localAddressList[SCTP_MAX_NUM_ADDRESSES][SCTP_MAX_IP_LEN],
-                            SCTP_ulpCallbacks ULPcallbackFunctions);
+int sctp_registerInstance(unsigned short localPort,
+                          unsigned short noOfInStreams,
+                          unsigned short noOfOutStreams,
+                          unsigned int   noOfLocalAddresses,
+                          unsigned char  localAddressList[SCTP_MAX_NUM_ADDRESSES][SCTP_MAX_IP_LEN],
+                          SCTP_ulpCallbacks ULPcallbackFunctions);
 
 int sctp_unregisterInstance(unsigned short instance_name);
 
@@ -670,10 +670,10 @@ int sctp_sendUdpData(int sfd, unsigned char* buf, int length,
 
 typedef void (*sctp_StdinCallback) (char*, int);
 
-int sctp_registerStdinCallback(sctp_StdinCallback sdf, 
+int sctp_registerStdinCallback(sctp_StdinCallback sdf,
                                  char* buffer, int length);
-								 
-int sctp_unregisterStdinCallback();							
+
+int sctp_unregisterStdinCallback();
 
 /**
  * this function registers a callback function for catching
@@ -755,12 +755,20 @@ int sctp_sendRawData(unsigned int associationID, short path_id,
 
 #endif
 
+#ifdef TD_DEBUG
+#warning Using memory allocation debugging functions!
+#include <sys/types.h>
+void* my_calloc(size_t nmemb, size_t size);
+void* my_malloc(size_t size);
+void my_free(void* p);
+#define calloc my_calloc
+#define malloc my_malloc
+#define free my_free
+#endif
+
 #ifdef __cplusplus
 }
 #endif
 
 
-
-
 #endif
-
